pitchtools.diatonic_pitch_name_to_chromatic_pitch_class_number
==============================================================

.. autofunction:: abjad.tools.pitchtools.diatonic_pitch_name_to_chromatic_pitch_class_number.diatonic_pitch_name_to_chromatic_pitch_class_number
